/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.cache.eviction;

import org.jboss.cache.CacheException;
import org.jboss.cache.Fqn;
import org.jboss.cache.TreeCache;

import java.util.Set;

/**
 *  Base class implementation of EvictionPolicy.
 * @author Ben Wang  2-2004
 */
public class BaseEvictionPolicy implements EvictionPolicy
{
   protected RegionManager regionManager_ = null;
   protected TreeCache cache_;

   public BaseEvictionPolicy() {
//      regionManager_ = new RegionManager(this);
   }

   /** EvictionPolicy interface implementation */

   public Region[] getRegions()
   {
      return regionManager_.getRegions();
   }

   public void evict(Fqn fqn) throws Exception
   {
      cache_.evict(fqn);
   }

   /**
    * 
    * @param fqn
    * @return Set of children name as Objects
    */
   public Set getChildrenNames(Fqn fqn) {
      try {
         return cache_.getChildrenNames(fqn);
      } catch (CacheException e) {
         e.printStackTrace();
      }
      return null;
   }

   public boolean hasChild(Fqn fqn) {
      return cache_.hasChild(fqn);
   }

   public Object getCacheData(Fqn fqn, Object key)
   {
      try {
         return cache_.get(fqn, key);
      } catch (CacheException e) {
         e.printStackTrace();
      }
      return null;
   }

   public int getWakeupIntervalSeconds()
   {
      return 0; // default value here.
   }

   public void configure(TreeCache cache)
   {
   }

}
