/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.cache.eviction;

import org.jboss.cache.Fqn;

/**
 * Value object used in evicted event node queue.
 * @see org.jboss.cache.eviction.Region
 *
 * @author Ben Wang 2-2004
 */
public class EvictedEventNode
{
   // Signal the operation types.
   public static final Integer ADD_EVENT = new Integer(0);
   public static final Integer REMOVE_EVENT = new Integer(1);
   public static final Integer VISIT_EVENT = new Integer(2);

   private Fqn fqn_;
   private Integer event_;

   public EvictedEventNode(Fqn fqn, Integer event)
   {
      setFqn(fqn);
      setEvent(event);
   }

   public EvictedEventNode(String fqn)
   {
      setFqn(Fqn.fromString(fqn));
   }

   public Fqn getFqn()
   {
      return fqn_;
   }

   public void setFqn(Fqn fqn)
   {
      this.fqn_ = fqn;
   }

   public void setEvent(Integer event) {
      event_ = event;
   }

   public Integer getEvent() {
      return event_;
   }
}
