/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.cache.eviction;

//import org.jboss.cache.TreeCache;
import org.jboss.cache.Fqn;
import org.jboss.cache.TreeCache;

import java.util.Set;

/**
 * Generic eviction policy interface.
 *
 * @author Ben Wang 2-2004
 */
public interface EvictionPolicy
{
   /**
    * Return all regions declared.
    * @return
    */
   Region[] getRegions();

   /**
    * Evict a node form the underlying cache.
    * @param fqn Node corresponds to this fqn.
    * @throws Exception
    */
   void evict(Fqn fqn) throws Exception;

   /**
    * Return children names as Objects
    * @param fqn
    * @return
    */
   Set getChildrenNames(Fqn fqn);

   /**
    * Is this a leaf node?
    * @param fqn
    * @return
    */
   boolean hasChild(Fqn fqn);

   Object getCacheData(Fqn fqn, Object key);

   /**
    * return eviction thread (if any) wake up interval in seconds.
    * @return
    */
   int getWakeupIntervalSeconds();

   /**
    * Method called to configure this implementation.
    */
   void configure(TreeCache cache);
}
