/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.cache.eviction;

import org.jboss.cache.Fqn;

/**
 * Value object used in queue.
 *
 * @author Ben Wang 2-2004
 */
public class NodeEntry
{
   private long modifiedTimeStamp_;
   private NodeEntry previous_;
   private NodeEntry next_;
   private Fqn fqn_;

   public NodeEntry(Fqn fqn)
   {
      setFqn(fqn);
   }

   public NodeEntry(String fqn)
   {
      setFqn(Fqn.fromString(fqn));
   }

    /**
     * Get modified time stamp. This stamp is created during the node is
     * processed so it has some fuzy tolerance in there.
     * @return
     */
   long getModifiedTimeStamp()
   {
      return modifiedTimeStamp_;
   }

   void setModifiedTimeStamp(long modifiedTimeStamp)
   {
      this.modifiedTimeStamp_ = modifiedTimeStamp;
   }

   NodeEntry getPrevious()
   {
      return previous_;
   }

   void setPrevious(NodeEntry previous)
   {
      this.previous_ = previous;
   }

   NodeEntry getNext()
   {
      return next_;
   }

   void setNext(NodeEntry next)
   {
      this.next_ = next;
   }

   Fqn getFqn()
   {
      return fqn_;
   }

   void setFqn(Fqn fqn)
   {
      this.fqn_ = fqn;
   }

}
