/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.cache.lock;

import EDU.oswego.cs.dl.util.concurrent.Sync;
import EDU.oswego.cs.dl.util.concurrent.ReentrantWriterPreferenceReadWriteLock;

/**
 * @author Bela Ban
 * @version $Id: BelasLockStrategy.java,v 1.1.4.2 2005/12/01 19:48:42 dimitris Exp $
 */
public class BelasLockStrategy implements LockStrategy {
   ReentrantWriterPreferenceReadWriteLock lock=new ReentrantWriterPreferenceReadWriteLock();

   public BelasLockStrategy() {
   }

   public Sync readLock() {
      return lock.readLock();
   }

   public Sync writeLock() {
      return lock.writeLock();
   }

   public Sync upgradeLockAttempt(long msecs) throws UpgradeException {
      boolean acquired;
      Sync    writeLock=lock.writeLock();

      try {
         acquired=writeLock.attempt(msecs);
         if(acquired) {
            lock.readLock().release();
            return writeLock;
         }
         else {
            return null;
         }
      }
      catch(InterruptedException iex) {
         throw new UpgradeException("failed upgrading lock", iex);
      }
   }
}
