/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.cache.lock;

import org.jboss.cache.CacheException;

import java.util.List;


/**
 * Thrown when a timeout occurred. used by operations with timeouts, e.g. lock
 * acquisition, or waiting for responses from all members.
 *
 * @author <a href="mailto:bela@jboss.org">Bela Ban</a>.
 * @version $Revision: 1.1.2.7 $
 *          <p/>
 *          <p><b>Revisions:</b>
 *          <p/>
 *          <p>Dec 28 2002 Bela Ban: first implementation
 */
public class TimeoutException extends CacheException
{
   List failed_members = null;

   public TimeoutException()
   {
      super();
   }

   public TimeoutException(List failed_members)
   {
      super();
      this.failed_members = failed_members;
   }

   public TimeoutException(String msg)
   {
      super(msg);
   }

   public TimeoutException(String msg, Throwable cause)
   {
      super(msg, cause);
   }

   public String toString()
   {
      String retval = super.toString();
      if (failed_members != null)
         retval += ", failed_members=" + failed_members;
      return retval;
   }
}
