/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.mq.il.ha.examples;

import javax.jms.JMSException;
import javax.naming.NamingException;

/**
 * 
 * Helps with manual testing of the HA JMS
 * 
 * @author  Ivelin Ivanov <ivelin@apache.org>
 *
 */
public interface HAJMSClientMBean extends org.jboss.system.ServiceMBean
{
  public abstract String getConnectionException();
  public abstract String getLastMessage() throws JMSException;
  public abstract void publishMessageToTopic(String text) throws JMSException;
  public abstract void sendMessageToQueue(String text) throws JMSException;
  
  /**
   * Registers durable subscribtion for the same topic and immediately disconnect.
   * Allows testing of recovery and fail-over via shared database. 
   * 
   * @throws JMSException
   */
  public void registerDurableSubscriberAndDisconnect() throws JMSException, NamingException;
  
  /**
   * Registers durable subscribtion for the same topic and wait for messages.
   * Allows testing of recovery and fail-over via shared database. 
   * 
   * @throws JMSException
   */
  public void registerDurableSubscriberAndReceiveMessages() throws JMSException, NamingException;

  public abstract void connectPublisher() throws NamingException, JMSException;
  public abstract void disconnect() throws NamingException, JMSException;
}
