/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.ha.httpsession.beanimpl.ejb;

import java.io.Serializable;

import org.jboss.invocation.Invocation;
import org.jboss.invocation.PayloadKey;
import org.jboss.proxy.Interceptor;

/** An InvokerInterceptor that places the client thread context ClassLoader
 * into the invocation for use by the s ServerTCLInterceptor.
 *
 * @see org.jboss.ha.httpsession.beanimpl.ejb.ServerTCLInterceptor
 *
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.1.2.3 $
 */
public class ClientTCLInterceptor
      extends Interceptor
      implements Serializable
{
   /** The serialVersionUID
    * @since 1.1.2.1
    */ 
   private static final long serialVersionUID = 1092404482795617680L;

   public ClientTCLInterceptor()
   {
   }

   // Public --------------------------------------------------------

   /** Add the current thread context ClassLoader to the invocation as a
    * transient value under the key "org.jboss.invocation.TCL"
    */
   public Object invoke(Invocation invocation)
         throws Throwable
   {
      ClassLoader tcl = Thread.currentThread().getContextClassLoader();
      invocation.setValue("org.jboss.invocation.TCL", tcl, PayloadKey.TRANSIENT);
      return getNext().invoke(invocation);
   }
}
