/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.ha.httpsession.beanimpl.ejb;

import org.jboss.ejb.plugins.AbstractInterceptor;
import org.jboss.invocation.Invocation;

/**
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.1.2.2 $
 */
public class ServerTCLInterceptor extends AbstractInterceptor
{
   public Object invokeHome(Invocation mi) throws Exception
   {
      ClassLoader prevTCL = Thread.currentThread().getContextClassLoader();
      ClassLoader tcl = (ClassLoader) mi.getValue("org.jboss.invocation.TCL");
      try
      {
         // Set the active TCL to that of the invocation TCL
         if( tcl != null )
            Thread.currentThread().setContextClassLoader(tcl);
         return getNext().invokeHome(mi);
      }
      finally
      {
         // Restore the incoming TCL if we overrode it
         if( tcl != null )
            Thread.currentThread().setContextClassLoader(prevTCL);
      }
   }

   public Object invoke(Invocation mi) throws Exception
   {
      ClassLoader prevTCL = Thread.currentThread().getContextClassLoader();
      ClassLoader tcl = (ClassLoader) mi.getValue("org.jboss.invocation.TCL");
      try
      {
         // Set the active TCL to that of the invocation TCL
         if( tcl != null )
            Thread.currentThread().setContextClassLoader(tcl);
         return getNext().invoke(mi);
      }
      finally
      {
         // Restore the incoming TCL if we overrode it
         if( tcl != null )
            Thread.currentThread().setContextClassLoader(prevTCL);
      }
   }
}
