/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.ha.httpsession.interfaces;

/**
 * Tag interface to make HttpSession serializable. Used to store the clustered HttpSession
 * in an entity bean.
 * Furthermore, it adds an areAttributesModified method used by the entity bean
 * to determine if the content attributes have been modified.
 * WARNING: the areAttributesModified method should not compare the creation and last
 *          access time but only the attributes and other specific values. Otherwise
 *          the state will be considered as changed for every request (which will cause
 *          to much cluster traffic.
 *
 * @see org.jboss.ha.httpsession.beanimpl.interfaces.ClusteredHttpSessionBusiness
 *
 * @author  <a href="mailto:sacha.labourey@cogito-info.ch">Sacha Labourey</a>.
 * @version $Revision: 1.2.4.5 $
 */
public interface SerializableHttpSession extends java.io.Serializable
{
   /** The serialVersionUID
    * @since 1.2
    */ 
   static final long serialVersionUID = -4806016296187171945L;

   /**
    * Method used by the entity bean
    * to determine if the content attributes have been modified.
    * WARNING: the areAttributesModified method should not compare the creation and last
    *          access time but only the attributes and other specific values. Otherwise
    *          the state will be considered as changed for every request (which will cause
    *          to much cluster traffic.
    *
    * @param previousVersion    A previous version of the HttpSession to be compared against.
    */
   public boolean areAttributesModified (SerializableHttpSession previousVersion);

   public long getContentCreationTime ();
   public long getContentLastAccessTime ();

   public void sessionHasBeenStored ();

   /**
    * is the session replicated sync- or asynchronously
    *
    * @see  org.jboss.metadata.WebMetaData
    */
   public int getReplicationTypeForSession ();
}
