/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package javax.resource.spi;

import javax.resource.ResourceException;

/**
 * The ConnectionEventListener interface provides for a callback mechanism
 * to enable objects to listen for events of the ConnectionEvent class.
 *
 * An Application server uses these events to manage its connection pools.
 */

public interface ConnectionEventListener extends java.util.EventListener {

    /**
     * Notifies the listener that a connection has been closed
     */
    public void connectionClosed( ConnectionEvent event );

    /**
     * Local transaction has been started
     */
    public void localTransactionStarted( ConnectionEvent event );

    /**
     * Local transaction has been committed
     */
    public void localTransactionCommitted( ConnectionEvent event );

    /**
     * Local transaction has been rolled back 
     */
    public void localTransactionRolledback( ConnectionEvent event );

    /**
     * Connection error has occurred
     */
    public void connectionErrorOccurred( ConnectionEvent event );
}
