/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package javax.resource.spi;

import javax.resource.ResourceException;

/**
 * A ManagedConnectionFactory is a factory for the creation of
 * ManagedConnection objects and ConnectionFactory objects.  It provides
 * methods which can be used to match ManagedConnetions.
 */

public interface ManagedConnectionFactory 
   extends java.io.Serializable
{
    /**
     * Creates a connection factory instance.
     */
    public Object createConnectionFactory() throws ResourceException;

    /**
     * Creates a connection factory instance.
     */
    public Object createConnectionFactory( ConnectionManager cxManager )
    	throws ResourceException;

    /**
     * Creates a new ManagedConnection
     */
    public ManagedConnection createManagedConnection( javax.security.auth.Subject subject, ConnectionRequestInfo cxRequestInfo ) throws ResourceException;

    /**
     * Tests object for equality
     */
    public boolean equals( Object other );

    /**
     * Gets the logwriter for this instance.
     */
    public java.io.PrintWriter getLogWriter() throws ResourceException;

    /**
     * Generates a hashCode for this object
     */
    public int hashCode();

    /**
     * Returns a matching connection from the set.
     */
    public ManagedConnection matchManagedConnections(
                                  java.util.Set connectionSet,
				  javax.security.auth.Subject subject,
                                  ConnectionRequestInfo cxRequestInfo )
		throws ResourceException;

    /**
     * Sets the logwriter for this instance.
     */
    public void setLogWriter( java.io.PrintWriter out ) throws ResourceException;
}
