/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package javax.xml.rpc.encoding;

import javax.xml.namespace.QName;

/** This is the base interface for the representation of a type mapping. A
 * TypeMapping implementation class may support one or more encoding styles.
 * 
 * For its supported encoding styles, a TypeMapping instance maintains a set of
 * tuples of the type {Java Class, SerializerFactory, DeserializerFactory,
 *    XML type-QName}. 
 * 
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.2.6.2 $
 */
public interface TypeMapping
{
   public DeserializerFactory getDeserializer(Class javaType, QName xmlType);
   public SerializerFactory getSerializer(Class javaType, QName xmlType);

   public String[] getSupportedEncodings();
   public void setSupportedEncodings(String[] encodingStyleURIs);

   public boolean isRegistered(Class javaType, QName xmlType);
   public void register(Class javaType, QName xmlType, SerializerFactory sf,
      DeserializerFactory dsf); 

   public void removeDeserializer(Class javaType, QName xmlType);
   public void removeSerializer(Class javaType, QName xmlType);
}
