/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package javax.xml.soap;

import java.io.InputStream;
import java.io.IOException;

/** A factory for creating SOAPMessage objects. 

A SAAJ client can create a MessageFactory object using the method newInstance,
 as shown in the following line of code. 

       MessageFactory mf = MessageFactory.newInstance();
 
 A standalone client (a client that is not running in a container) can use the
 newInstance method to create a MessageFactory object.
 
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.1.6.2 $
 */
public abstract class MessageFactory
{
   private static final String DEFAULT_MSG_FACTORY =
      "org.apache.axis.soap.MessageFactoryImpl";

   public MessageFactory()
   {
   }

   /** Creates a new MessageFactory object that is an instance of the default
    * implementation.
    *  
    * @return
    * @throws SOAPException
    */ 
   public static MessageFactory newInstance() throws SOAPException
   {
      MessageFactory factory = null;
      String factoryName = null;

      try
      {
         factoryName = System.getProperty("javax.xml.soap.MessageFactory",
            DEFAULT_MSG_FACTORY);
         ClassLoader loader = Thread.currentThread().getContextClassLoader();
         Class factoryClass = loader.loadClass(factoryName);
         factory = (MessageFactory) factoryClass.newInstance();
      }
      catch(Throwable t)
      {
         throw new SOAPException("Failed to create MessageFactory: "+factoryName, t);
      }
      return factory;
   }

   public abstract SOAPMessage createMessage() throws SOAPException;
   public abstract SOAPMessage createMessage(MimeHeaders headers, InputStream in)
      throws IOException, SOAPException;
}
