/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package javax.xml.soap;

/** A factory for creating SOAPConnection objects. Implementation of this class
 * is optional. If SOAPConnectionFactory.newInstance() throws an
 * UnsupportedOperationException then the implementation does not support the
 * SAAJ communication infrastructure. Otherwise SOAPConnection objects can be
 * created by calling createConnection() on the newly created
 * SOAPConnectionFactory object.
 *  
 * @author Scott.Stark@jboss.org
 * @author Thomas.Diesler@jboss.org
 * @version $Revision: 1.2.4.2 $
 */
public abstract class SOAPConnectionFactory
{
   private static final String JBOSS_SOAP_CONN_FACTORY =
           "org.jboss.webservice.soap.SOAPConnectionFactoryImpl";

   private static final String AXIS_SOAP_CONN_FACTORY =
           "org.apache.axis.soap.SOAPConnectionFactoryImpl";

   public SOAPConnectionFactory()
   {
   }

   /** Creates an instance of the default SOAPConnectionFactory object. 
    * 
    * @return
    * @throws SOAPException
    * @throws UnsupportedOperationException
    */
   public static SOAPConnectionFactory newInstance()
           throws SOAPException, UnsupportedOperationException
   {
      SOAPConnectionFactory factory = null;
      String factoryName = null;

      try
      {
         factoryName = System.getProperty("javax.xml.soap.SOAPConnectionFactory", JBOSS_SOAP_CONN_FACTORY);
         ClassLoader loader = Thread.currentThread().getContextClassLoader();

         Class factoryClass = null;
         try
         {
            factoryClass = loader.loadClass(factoryName);
         }
         catch (ClassNotFoundException ignore)
         {
            factoryName = AXIS_SOAP_CONN_FACTORY;
            factoryClass = loader.loadClass(factoryName);
         }

         factory = (SOAPConnectionFactory)factoryClass.newInstance();
      }
      catch (Throwable t)
      {
         throw new SOAPException("Failed to create SOAPConnectionFactory: " + factoryName, t);
      }
      return factory;
   }

   public abstract SOAPConnection createConnection() throws SOAPException;
}
