/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.net.axis;

import javax.naming.Reference;
import javax.naming.Referenceable;
import javax.naming.StringRefAddr;

/**
 * <p>The attacheable service implementation 
 * allows to bind axis service instances into JNDI 
 * without loosing the configuration link to their engine/deployer.</p> 
 * <p>Configuration pointers are reinstalled 
 * by a dedicated context attribute that allows to identify a 
 * target configuration when deserialized by the associated 
 * ServiceFactory.</p>
 * @see ServiceFactory
 * @since  26.04.02
 * @author <a href="mailto:Christoph.Jung@infor.de">Christoph G. Jung</a>
 * @version $Revision: 1.1.2.4 $
 */

public class AttacheableService implements Referenceable
{

   //
   // Attributes
   //

   /** 
    * the real axis service implementation that 
    * regularly looses its configuration
    */

   protected String serviceClass;

   /** this is what we need to find the important part, which is the
    *  engine configuration, again. 
    */
   protected String rootContext;

   //
   // Constructors
   //

   /** 
    * Creates a new ServiceFactory.
    * @param service the axis service
    */

   public AttacheableService(String serviceClass, String rootContext)
   {
      this.serviceClass = serviceClass;
      this.rootContext = rootContext;
   }

   //
   // Naming API
   //

   public Reference getReference()
   {
      Reference myRef =
         new Reference(serviceClass, ServiceFactory.class.getName(), null);
      myRef.add(new StringRefAddr(Constants.CONFIGURATION_CONTEXT, rootContext));
      return myRef;
   }

}
