/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.net.axis;

import org.jboss.axis.encoding.ser.BaseDeserializerFactory;

import javax.xml.namespace.QName;
import java.util.Map;

/**
 * Deserializer Factory that may be parameterized with additional
 * options.
 * <br>
 * <h3>Change History</h3>
 * <ul>
 * </ul>
 * @created 06.04.2002
 * @author <a href="mailto:Christoph.Jung@infor.de">Christoph G. Jung</a>
 * @version $Revision: 1.1.4.4 $
 */

public class ParameterizableDeserializerFactory extends BaseDeserializerFactory
{

   // 
   // Attributes
   // 
	
   protected Map options;
	
   //
   // Constructors
   //
		
   /** regular constructor */
   public ParameterizableDeserializerFactory(Class deserializerType, Class javaType, QName xmlType)
   {
      super(deserializerType, xmlType, javaType);
   }

   /** the extended constructor that is parameterized */
   public ParameterizableDeserializerFactory(Class deserializerType, Class javaType, QName xmlType, Map options)
   {
      super(deserializerType, xmlType, javaType);
      this.options = options;
   }

   //
   // public API
   //

   /** return options */
   protected Map getOptions()
   {
      return options;
   }

   /** set options */
   protected void setOptions(Map options)
   {
      this.options = options;
   }

   /** return a new deserializer that we equip with the right options */
   public javax.xml.rpc.encoding.Deserializer getDeserializerAs(String mechanismType)
   {
      javax.xml.rpc.encoding.Deserializer deser = super.getDeserializerAs(mechanismType);
      if (deser instanceof ParameterizableDeserializer)
      {
         ((ParameterizableDeserializer)deser).setOptions(options);
      }
      return deser;
   }

}
