/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
// $Id: ServiceClassLoaderAwareWSDDHandlerProvider.java,v 1.3.2.4 2005/12/01 19:49:13 dimitris Exp $
package org.jboss.net.axis;

import org.jboss.axis.EngineConfiguration;
import org.jboss.axis.Handler;
import org.jboss.axis.deployment.wsdd.WSDDService;
import org.jboss.axis.deployment.wsdd.providers.WSDDHandlerProvider;

/**
 * <p>
 * A subclass of the official handler provider that
 * is able to load the specified handler classes from
 * the service deployment classloader.
 * </p>
 * @author jung
 * @since 12.03.2003
 * @version $Revision: 1.3.2.4 $
 */

public class ServiceClassLoaderAwareWSDDHandlerProvider
        extends WSDDHandlerProvider
{

   /* (non-Javadoc)
    * @see org.jboss.axis.deployment.wsdd.WSDDProvider#newProviderInstance(org.jboss.axis.deployment.wsdd.WSDDService, org.jboss.axis.EngineConfiguration)
    */
   public Handler newProviderInstance(WSDDService arg0,
                                      EngineConfiguration arg1)
           throws Exception
   {

      Deployment deployment = (Deployment)arg0.getParametersTable().
              get(Constants.SERVICE_DEPLOYMENT_PARAMETER);

      if (deployment != null)
      {
         ClassLoader loader = deployment.getDeploymentLoader();
         ClassLoader old = Thread.currentThread().getContextClassLoader();
         Thread.currentThread().setContextClassLoader(loader);
         try
         {
            return super.newProviderInstance(arg0, arg1);
         }
         finally
         {
            Thread.currentThread().setContextClassLoader(old);
         }
      }
      else
      {
         return super.newProviderInstance(arg0, arg1);
      }
   }

}
