/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.net.axis.security;

import javax.xml.namespace.QName;

import org.apache.ws.security.WSConstants;

/**
 * <dl>
 * <dt><b>Title: </b><dd>Security Constants</dd>
 * <p>
 * <dt><b>Description: </b><dd>Constants used by the WSSecurity handlers</dd>
 * <p>
 * </dl>
 * @author <a href="mailto:jasone@greenrivercomputing.com">Jason Essington</a>
 * @version $Revision: 1.1.6.2 $
 */
public interface SecurityConstants
{
   /** Configuration prameter for the {@link org.jboss.net.axis.security.handler.WSSRequestHandler} and 
    * {@link org.jboss.net.axis.security.handler.WSSResponseHandler} used to define the jndi name of the
    * {@link org.jboss.security.SecurityDomain} that will be serving the handlers.*/
   public static final String HANDLER_SEC_DOMAIN = "securityDomain";

   /**
    * Configuration prameter for the {@link org.jboss.net.axis.security.handler.WSSRequestHandler} and 
    * {@link org.jboss.net.axis.security.handler.WSSResponseHandler} used to define the 
    * {@link org.jboss.net.axis.security.JBossCrypto} implementation that should be used by the handlers.
    */
   public static final String HANDLER_CRYPTO_CLASS = "cryptoImplementation";

   public static final QName SECURITY_HEADER_QNAME = new QName(WSConstants.WSSE_NS, WSConstants.WSSE_LN);

   /** 
    * Map of Keystore aliases that were used to sign the incoming request. 
    * The map key is the actor/role and the value is the Keystore alias of the certificate used to sign.
    */
   public static final String MC_REQ_SIGNERS = "security.request.signers";
}
