/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.net.axis.server;

import org.jboss.axis.AxisFault;
import org.jboss.axis.server.AxisServer;
import org.jboss.axis.transport.http.AdminServlet;

/**
 * slightly patched admin servlet to contact the right server
 * @created 9.9.2002
 * @author jung
 * @version $Revision: 1.1.2.5 $
 */

public class AxisAdminServlet extends AdminServlet
{

   /** reference to the server */
   protected AxisServer server = null;

   /** Creates new AxisServlet */
   public AxisAdminServlet()
   {
   }

   /** override AxisServlet.getEngine() in order to redirect to
    *  the corresponding AxisEngine.
    */
   public AxisServer getEngine() throws AxisFault
   {
      if (server == null)
      {
         // we need to extract the engine from the 
         // rootcontext
         String installation = getInitParameter(org.jboss.net.axis.Constants.CONFIGURATION_CONTEXT);
         // call the static service method to find the installed engine
         try
         {
            server = JMXEngineConfigurationFactory.newJMXFactory(installation).getAxisServer();
         }
         catch (NullPointerException e)
         {
            throw new AxisFault("Could not access JMX configuration factory.", e);
         }
      }

      return server;
   }

}
