/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.net.axis.server;

import javax.activation.CommandMap;
import javax.activation.MailcapCommandMap;

import org.jboss.logging.Logger;

/** A pojo service which can be used to populate the JAF MailcapCommandMap
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.2.6.2 $
 */
public class JAFConfigService
{
   private static Logger log = Logger.getLogger(JAFConfigService.class);
   private String[] mailcaps = {
      "text/xml;;x-java-content-handler=org.jboss.net.axis.jaf.XMLDataContentHandler",
      "application/xml;;x-java-content-handler=org.jboss.net.axis.jaf.XMLDataContentHandler"      
   };

   public String[] getMailcaps()
   {
      return mailcaps;
   }
   public void setMailcaps(String[] mailcaps)
   {
      this.mailcaps = mailcaps;
   }

   public void start() throws Exception
   {
      CommandMap commandMap = CommandMap.getDefaultCommandMap();
      if( commandMap instanceof MailcapCommandMap )
      {
         MailcapCommandMap mailMap = (MailcapCommandMap) commandMap;
         for(int n = 0; n < mailcaps.length; n ++)
         {
            String mailcap = mailcaps[n];
            mailMap.addMailcap(mailcap);
            log.debug("Added mailcap: "+mailcap);
         }
      }
      else
      {
         throw new Exception("Cannot handle non-MailcapCommandMap, map="
            +commandMap);
      }
   }
}
