/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.net.jmx.adaptor;

import org.jboss.axis.encoding.SerializationContext;
import org.jboss.axis.encoding.ser.SimpleSerializer;
import org.jboss.axis.wsdl.fromJava.Types;
import org.w3c.dom.Element;

import javax.management.ObjectName;
import javax.xml.namespace.QName;

/**
 * Serializer specialized to turn JMX-Objectnames into
 * corresponding XML-types.
 * @since 26.04.2002
 * @author <a href="mailto:a_taherkordi@users.sourceforge.net">Alireza Taherkordi</a>
 * @author <a href="mailto:Christoph.Jung@infor.de">Christoph G. Jung</a>
 * @version $Revision: 1.7.4.3 $
 */

public class ObjectNameSer extends SimpleSerializer
{

   public ObjectNameSer(Class javaType, QName xmlType)
   {
      super(javaType, xmlType);
   }

   public String getValueAsString(Object value, SerializationContext context)
   {
      return ((ObjectName)value).getCanonicalName();
   }

   /* (non-Javadoc)
    * @see org.jboss.axis.encoding.Serializer#writeSchema(java.lang.Class, org.jboss.axis.wsdl.fromJava.Types)
    */
   public Element writeSchema(Class clazz, Types types) throws Exception
   {
      // ComplexType representation of SimpleType bean class
      Element complexType = types.createElement("complexType");
      //types.writeSchemaElement(xmlType, complexType);
      types.writeSchemaElement(xmlType, complexType);
      complexType.setAttribute("name", xmlType.getLocalPart());

      // Produce simpleContent extending base type.
      Element simpleContent = types.createElement("simpleContent");
      complexType.appendChild(simpleContent);
      Element extension = types.createElement("extension");
      simpleContent.appendChild(extension);

      // Get the base type from the "value" element of the bean
      String base = "string";
      extension.setAttribute("base", base);
      // done
      return complexType;
   }

}