/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.mx.remoting;

import org.jboss.remoting.network.NetworkNotification;

import javax.management.NotificationListener;
import javax.management.Notification;
import javax.management.NotificationFilter;

/**
 * MBeanRemovalListener is a listener for mbean removal events for a server and
 * when it is received, will destroy the client proxy
 * 
 * @author <a href="mailto:jhaynie@vocalocity.net">Jeff Haynie</a>
 * @version $Revision: 1.1.2.2 $
 */
public class MBeanRemovalListener implements NotificationListener, NotificationFilter
{
    private final MBeanServerClientInvokerProxy proxy;

    MBeanRemovalListener (MBeanServerClientInvokerProxy proxy)
    {
        this.proxy = proxy;
    }
    public void handleNotification(Notification notification, Object object)
    {
        // we receieved a network failure event, remove it
        this.proxy.destroy();
    }

    public boolean isNotificationEnabled(Notification notification)
    {
        if (notification.getType().equals(NetworkNotification.SERVER_REMOVED))
        {
            NetworkNotification nn=(NetworkNotification)notification;
            return nn.getIdentity().getJMXId().equals(proxy.getServerId());
        }
        return false;
    }
}
