/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package javax.management;

/**
 * A qualified string that is an argument to a query.<p>
 * 
 * @author  <a href="mailto:Adrian.Brock@HappeningTimes.com">Adrian Brock</a>.
 * @version $Revision: 1.2.6.2 $
 */
/*package*/ class QualifiedAttributeValueExp
   extends AttributeValueExp
{
   // Constants ---------------------------------------------------

   // Attributes --------------------------------------------------

   /**
    * The class name
    */
   private String className;

   // Static  -----------------------------------------------------

   // Constructors ------------------------------------------------

   /**
    * Construct an attribute value expression for the passed class and 
    * attribute name
    *
    * @param className the class name
    * @param value the attribute name
    */
   public QualifiedAttributeValueExp(String className, String value)
   {
      super(value);
      this.className = className;
   }

   // Public ------------------------------------------------------

   // ValueExp Implementation -------------------------------------

   public ValueExp apply(ObjectName name)
      throws BadStringOperationException,
             BadBinaryOpValueExpException,
             BadAttributeValueExpException,
             InvalidApplicationException
   {
      try
      {
         ObjectInstance instance = getMBeanServer().getObjectInstance(name);
         if (instance.getClassName().equals(className))
            return super.apply(name);
      }
      catch (Exception e)
      {
         // REVIEW: What happens here? Should this happen?
         return null;
      }
      throw new InvalidApplicationException(name + "\n" + className);
   }

   // Object overrides --------------------------------------------

   public String toString()
   {
      return className + "." + getAttributeName();
   }

   // Protected ---------------------------------------------------

   // Package Private ---------------------------------------------

   // Private -----------------------------------------------------

   // Inner Classes -----------------------------------------------
}
