/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.mx.server;

import java.lang.reflect.Method;

/** A dispatcher used by the AbstractMBeanInvoker class for the attribute
 * getter and setter dispatch.
 * 
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.1.2.3 $
 */
public class AttributeDispatcher
   extends ReflectedDispatcher
{
   private Method getter;
   private Method setter;

   public AttributeDispatcher(Object target, Method getter, Method setter)
   {
      super(target, getter);
      this.getter = getter;
      this.setter = setter;
   }

   /** Dispatch the attribute set or get. A get is identified by a dispatch
    * with a null args value.
    * 
    * @return the result of the attribute accessor invocation
    * @throws InvocationException
    */ 
   public Object dispatch(Object[] args) throws InvocationException
   {        
      Object value = null;
      try
      {
         if( args == null )
            value = getter.invoke(target, args);
         else
            value = setter.invoke(target, args);
      }
      catch (Throwable t)
      {
         handleInvocationExceptions(t);
         return null;
      }
      return value;
   }
}
