/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.mq.il.uil.multiplexor;
import java.io.IOException;
import java.io.OutputStream;

/**
 *  Objects of this class provide and an OutputStream to a StreamMux. Objects of
 *  this class are created by a StreamMux object.
 *
 * @author     Hiram Chirino (Cojonudo14@hotmail.com)
 * @created    August 16, 2001
 * @version    $Revision: 1.2.8.1 $
 */
class MuxOutputStream extends OutputStream {

   StreamMux        streamMux;
   short            streamId;

   byte             buffer[];
   short            bufferLength;

   MuxOutputStream( StreamMux mux, short id ) {
      streamMux = mux;
      streamId = id;
      buffer = new byte[streamMux.frameSize];
      bufferLength = 0;
   }

   /**
    *  Closes this output stream and releases any system resources.
    *
    * @exception  IOException  Description of Exception
    */
   public void close()
      throws IOException {
      streamMux.closeStream( streamId );
   }

   /**
    *  Flushes this output stream and forces any buffered output bytes to be
    *  written out.
    *
    * @exception  IOException  Description of Exception
    */
   public void flush()
      throws IOException {
      if ( bufferLength > 0 ) {
         flushBuffer();
      }
      streamMux.flush();
   }

   /**
    * @param  data             Description of Parameter
    * @exception  IOException  Description of Exception
    */
   public void write( int data )
      throws IOException {
      byte b = ( byte )data;
      buffer[bufferLength] = b;
      bufferLength++;

      if ( bufferLength == streamMux.frameSize ) {
         flushBuffer();
      }
   }

   /**
    *  Flushes the internal buffer to the multiplexor.
    *
    * @exception  IOException  Description of Exception
    */
   private void flushBuffer()
      throws IOException {
      streamMux.write( this, buffer, bufferLength );
      bufferLength = 0;
   }
}
