/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.remoting.detection;

import java.io.Serializable;

import org.jboss.remoting.InvokerLocator;
import org.jboss.remoting.ident.Identity;

/**
 * Detection is an MBean Notification that is fired by
 * Detectors when remote servers are found or lost on the Network.
 *
 * @author <a href="mailto:jhaynie@vocalocity.net">Jeff Haynie</a>
 * @version $Revision: 1.1.4.2 $
 */
public class Detection implements Serializable
{
    static final long serialVersionUID = -8401843787362355866L;
    private final InvokerLocator locators[];
    private final Identity identity;
    private int hashCode;

    public Detection (Identity identity, InvokerLocator locators[])
    {
        this.locators = locators;
        this.identity = identity;
        this.hashCode = identity.hashCode();
        if (locators!=null)
        {
            for (int c=0;c<locators.length;c++)
            {
                this.hashCode+=locators[c].hashCode() - 10000;
            }
        }
    }
    public boolean equals (Object obj)
    {
        if (obj instanceof Detection)
        {
            return hashCode==obj.hashCode();
        }
        return false;
    }
    public int hashCode ()
    {
        return hashCode;
    }

    public String toString ()
    {
        return "Detection [identity:"+identity+",locators:"+(locators==null?0:locators.length)+"]";
    }
    /**
     * return the jboss identity
     *
     * @return
     */
    public final Identity getIdentity ()
    {
        return identity;
    }
    /**
     * return the locators for the server
     *
     * @return
     */
    public final InvokerLocator[] getLocators ()
    {
        return locators;
    }
}
