/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.remoting.loading;

import org.jboss.remoting.RemoteMethodInvocation;

/**
 * ClassRequestedMethodInvocationResult is sent back with a class bytes that was required and the original
 * invocation to be re-invoked with the new class bytes.
 * 
 * @author <a href="mailto:jhaynie@vocalocity.net">Jeff Haynie</a>
 * @version $Revision: 1.1.4.1 $
 */
public class ClassRequestedMethodInvocationResult extends org.jboss.remoting.RemoteMethodInvocationResult
{
    static final long serialVersionUID = -1523959117367652488L;
    private final ClassBytes classBytes;
    private final RemoteMethodInvocation originalInvocation;

    public ClassRequestedMethodInvocationResult (String sessionId,ClassBytes classBytes, RemoteMethodInvocation originalInvocation)
        throws java.io.IOException
    {
        super(sessionId,null,false,(originalInvocation==null?null:originalInvocation.getPayload()));
        this.classBytes = classBytes;
        this.originalInvocation = originalInvocation;
    }
    public org.jboss.remoting.loading.ClassBytes getRequestedClass ()
    {
        return classBytes;
    }
    public org.jboss.remoting.RemoteMethodInvocation getOriginalInvocation ()
    {
        return originalInvocation;
    }
}
