/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.remoting.transport.async;

import java.io.IOException;

import org.jboss.remoting.ConnectionFailedException;
import org.jboss.remoting.InvokerLocator;

/**
 * An AsynchChannel allows you to transport bytes of data
 * back and forth between a client and a server in a async 
 * manner.
 * 
 * This interace abstraction is here so that it can be implemented 
 * using both the Blocking and Non-blocking IO APIs.
 * 
 * @author <a href="mailto:hiram@coredevelopers.net">Hiram Chirino</a>
 */
public interface Channel {
	
	/**
	 * opens a connection to another server.
	 * 
	 * @param uri
	 * @param localURI
	 * @param listner
	 * @throws IOException
	 * @throws ConnectionFailedException
	 */
	public void open(InvokerLocator uri, ChannelListner listner)
		throws IOException, ConnectionFailedException;

	/**
	 * starts an accepted connection.
	 * 
	 * @param listner
	 * @throws IOException
	 */
	public void open(ChannelListner listner)
		throws IOException;


	public void close() throws IOException;

	/**
	 * Sends an asynch packet of data down the channel.  It does not 
	 * wait wait for a response if possible.
	 */
	public void send(byte[][] data) throws IOException;
	
}
