/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.remoting.transport.mock;

import java.io.IOException;
import java.io.InputStream;

import org.jboss.remoting.InvokerLocator;
import org.jboss.remoting.ServerInvoker;
/**
 * MockServerInvoker
 * 
 * @author <a href="mailto:jhaynie@vocalocity.net">Jeff Haynie</a>
 * @version $Revision: 1.3.2.1 $
 */
public class MockServerInvoker extends ServerInvoker
{
    boolean loaded=false;

    public MockServerInvoker (InvokerLocator locator)
    {
       super(locator);
    }

    /**
     * returns true if the transport is bi-directional in nature, for example,
     * SOAP in unidirectional and SOCKETs are bi-directional (unless behind a firewall
     * for example).
     *
     * @return
     */
    public boolean isTransportBiDirectional ()
    {
        return false;
    }

    public byte[] getClassBytes (String className)
    {
        // this is just a test to dynamically load a class
        if (className.equals("Bar") && loaded==false)
        {
            InputStream in = null;
            try
            {
                String packageName = org.jboss.remoting.loading.ClassUtil.getPackageName(getClass());
                String name = packageName.replace('.','/')+"/test/Bar.xclass";
                log.debug("attempting to load Bar from: "+name);
                in = this.getClass().getClassLoader().getResourceAsStream(name);
                if (in!=null)
                {
                    byte buf[]=read(in);
                    addClass(new org.jboss.remoting.loading.ClassBytes(className,buf));
                    loaded=true;
                    return buf;
                }
            }
            catch (IOException e)
            {

            }
            finally
            {
                if (in!=null)
                {
                    try { in.close(); } catch (Exception ig) {}
                    in=null;
                }
            }
        }

        return super.getClassBytes(className);
    }
}
