/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.remoting.transport.rmi;

import java.io.IOException;
import java.rmi.RemoteException;

import org.jboss.remoting.ConnectionFailedException;
import org.jboss.remoting.InvokerLocator;
import org.jboss.remoting.RemoteClientInvoker;

/**
 * RMIClientInvoker
 *
 * @author <a href="mailto:jhaynie@vocalocity.net">Jeff Haynie</a>
 * @author <a href="mailto:telrod@vocalocity.net">Tom Elrod</a>
 * @version $Revision: 1.4.2.1 $
 */
public class RMIClientInvoker extends RemoteClientInvoker
{
    private RMIServerInvokerInf server;

    public RMIClientInvoker (InvokerLocator locator)
    {
        super(locator);
    }

    /**
     * get the server stub
     *
     * @param server
     */
    public void setServerStub (RMIServerInvokerInf server)
    {
        this.server = server;
        System.err.println(this.server);
    }

    /**
     * return the RMI server stub
     *
     * @return
     */
    public RMIServerInvokerInf getServerStub ()
    {
        return this.server;
    }

    /**
     * subclasses must implement this method to provide a hook to connect to the remote server, if this applies
     * to the specific transport. However, in some transport implementations, this may not make must difference since
     * the connection is not persistent among invocations, such as SOAP.  In these cases, the method should
     * silently return without any processing.
     *
     * @throws ConnectionFailedException
     */
    protected void handleConnect ()
            throws ConnectionFailedException
    {
    }

    /**
     * subclasses must implement this method to provide a hook to disconnect from the remote server, if this applies
     * to the specific transport. However, in some transport implementations, this may not make must difference since
     * the connection is not persistent among invocations, such as SOAP.  In these cases, the method should
     * silently return without any processing.
     */
    protected void handleDisconnect ()
    {
    }

    protected byte[] transport (String sessionId, byte buffer[])
            throws IOException, ConnectionFailedException
    {
        if (this.server==null)
        {
            throw new IOException("Server stub hasn't been set!");
        }
        try
        {
            return server.transport(buffer);
        }
        catch (RemoteException e)
        {
            throw new ConnectionFailedException(e.getMessage());
        }
    }
}
