/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.remoting.transport.soap.axis;

import java.io.IOException;
import java.rmi.RemoteException;

import org.jboss.remoting.InvokerRegistry;
import org.jboss.remoting.ServerInvoker;

/**
 * SOAP binding
 *
 * @author <a href="mailto:telrod@e2technologies.net">Tom Elrod</a>
 * @author <a href="jhaynie@vocalcoity.net">Jeff Haynie</a>
 */
public class AxisSOAPConnectorSoapBindingImpl implements AxisSOAPConnector
{
    private ServerInvoker invoker;

    /**
     * server invoker will call invoke to pass a URI to himself
     */
    public void initialize(String invokerURI) throws java.rmi.RemoteException
    {
        ServerInvoker invokers[] = InvokerRegistry.getServerInvokers();
        if (invokers!=null)
        {
            for (int c=0;c<invokers.length;c++)
            {
                if (invokers[c].getLocator().getLocatorURI().equals(invokerURI))
                {
                    invoker = invokers[c];
                    break;
                }
            }
        }
        if (invoker==null)
        {
            throw new RemoteException("Couldn't find Invoker with URI: "+invokerURI);
        }
    }

    /**
     * This method is used to receive the client SOAP calls and pass them on to the
     * AxisSOAPConnectorServer via an MBeanServer transport call.  Will then return the
     * results to the calling SOAP client.
     *
     * @param data
     * @return byte array
     * @throws IOException
     * @throws java.rmi.RemoteException
     */
    public byte[] transport (byte[] data) throws IOException, java.rmi.RemoteException
    {
        if (invoker == null)
        {
            throw new IOException("AXIS Service hasn't been initialized");
        }
        return invoker.invoke(data);
    }




}
