/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.remoting.transport.soap.axis;

import java.io.IOException;

/**
 * SOAP skeleton
 *
 * @author <a href="mailto:telrod@e2technologies.net">Tom Elrod</a>
 * @author <a href="jhaynie@vocalcoity.net">Jeff Haynie</a>
 */
public class AxisSOAPConnectorSoapBindingSkeleton implements AxisSOAPConnector,
        org.jboss.axis.wsdl.Skeleton
{
    private AxisSOAPConnector impl;
    private static java.util.Map _myOperations = new java.util.Hashtable();
    private static java.util.Collection _myOperationsList = new java.util.ArrayList();

    /**
    * Returns List of OperationDesc objects with this name
    */
    public static java.util.List getOperationDescByName(String methodName) {
        return (java.util.List)_myOperations.get(methodName);
    }

    /**
    * Returns Collection of OperationDescs
    */
    public static java.util.Collection getOperationDescs() {
        return _myOperationsList;
    }

    static {
        org.jboss.axis.description.OperationDesc _oper;
        org.jboss.axis.description.FaultDesc _fault;
        org.jboss.axis.description.ParameterDesc [] _params;
        _params = new org.jboss.axis.description.ParameterDesc [] {
            new org.jboss.axis.description.ParameterDesc(new javax.xml.namespace.QName("", "in0"), org.jboss.axis.description.ParameterDesc.IN, new javax.xml.namespace.QName("http://www.w3.org/2001/XMLSchema", "base64Binary"), byte[].class, false, false),
        };
        _oper = new org.jboss.axis.description.OperationDesc("transport", _params, new javax.xml.namespace.QName("", "invokeReturn"));
        _oper.setReturnType(new javax.xml.namespace.QName("http://www.w3.org/2001/XMLSchema", "base64Binary"));
        _oper.setElementQName(new javax.xml.namespace.QName("urn:AxisSOAPConnector", "transport"));
        _oper.setSoapAction("");
        _myOperationsList.add(_oper);
        if (_myOperations.get("transport") == null) {
            _myOperations.put("transport", new java.util.ArrayList());
        }
        ((java.util.List)_myOperations.get("transport")).add(_oper);
        _params = new org.jboss.axis.description.ParameterDesc [] {
            new org.jboss.axis.description.ParameterDesc(new javax.xml.namespace.QName("", "in0"), org.jboss.axis.description.ParameterDesc.IN, new javax.xml.namespace.QName("http://www.w3.org/2001/XMLSchema", "string"), String.class, false, false),
        };
        _oper = new org.jboss.axis.description.OperationDesc("initialize", _params, null);
        _oper.setElementQName(new javax.xml.namespace.QName("urn:AxisSOAPConnector", "initialize"));
        _oper.setSoapAction("");
        _myOperationsList.add(_oper);
        if (_myOperations.get("initialize") == null) {
            _myOperations.put("initialize", new java.util.ArrayList());
        }
        ((java.util.List)_myOperations.get("initialize")).add(_oper);
        _params = new org.jboss.axis.description.ParameterDesc [] {
            new org.jboss.axis.description.ParameterDesc(new javax.xml.namespace.QName("", "in0"), org.jboss.axis.description.ParameterDesc.IN, new javax.xml.namespace.QName("http://www.w3.org/2001/XMLSchema", "string"), String.class, false, false),
        };
    }

    public AxisSOAPConnectorSoapBindingSkeleton() {
        this.impl = new AxisSOAPConnectorSoapBindingImpl();
    }

    public AxisSOAPConnectorSoapBindingSkeleton(AxisSOAPConnector impl) {
        this.impl = impl;
    }

    public byte[] transport (byte[] in0) throws IOException, java.rmi.RemoteException
    {
        return impl.transport(in0);
    }

    public void initialize(String in0) throws java.rmi.RemoteException
    {
        impl.initialize(in0);
    }


}
