/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package test;

import junit.framework.AssertionFailedError;
import junit.framework.TestCase;
import junit.framework.TestResult;
import org.jboss.logging.Logger;

import java.util.Iterator;
import java.util.List;

/**
 * Extends regular JUnit TestResult so can run multiple test methods
 * within a single TestCase class.
 * @see MultipleTestCase
 * @author <a href="mailto:telrod@e2technologies.net">Tom Elrod</a>
 */
public class MultipleTestResult extends TestResult
{
    private static final Logger log = Logger.getLogger(MultipleTestResult.class);

    protected void run(final TestCase test)
    {
        if(test instanceof MultipleTestCase)
        {
            startTest(test);

            MultipleTestCase mTest = (MultipleTestCase) test;
            List testMethods = mTest.getTestMethods();
            Iterator itr = testMethods.iterator();
            while(itr.hasNext())
            {
                try
                {
                    String methodName = (String) itr.next();
                    log.debug("running test method " + methodName);
                    mTest.runBare(methodName);
                }
                catch(AssertionFailedError e)
                {
                    addFailure(test, e);
                }
                catch(ThreadDeath e)
                { // don't catch ThreadDeath by accident
                    throw e;
                }
                catch(Throwable e)
                {
                    addError(test, e);
                }
            }
            endTest(test);

        }
        else
        {
            super.run(test);
        }
    }

}