/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package javax.security.auth.callback;

import java.io.Serializable;
import java.util.Arrays;

/** The JAAS 1.0 classes for use of the JAAS authentication classes with
 * JDK 1.3. Use JDK 1.4+ to use the JAAS authorization classes provided by
 * the version of JAAS bundled with JDK 1.4+.
 *
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.1.2.3 $
 */
public class PasswordCallback implements Callback, Serializable
{
   private String prompt;
   private boolean echoOn;
   private char[] password;

   public PasswordCallback(String prompt, boolean echoOn)
   {
      this.prompt = prompt;
      this.echoOn = echoOn;
   }

   public String getPrompt()
   {
      return prompt;
   }
   public boolean isEchoOn()
   {
      return echoOn;
   }

   public void clearPassword()
   {
      Arrays.fill(password, ' ');
   }
   public char[] getPassword()
   {
      char[] tmpPassword = null;
      if( password != null )
         tmpPassword = (char[]) password.clone();
      return tmpPassword;
   }
   public void setPassword(char[] password)
   {
      if( password != null )
         password = (char[]) password.clone();
      this.password = password;
   }
}
