/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package javax.security.auth.login;

import java.util.Map;

/** An alternate implementation of the JAAS 1.0 Configuration class that deals
 * with ClassLoader shortcomings that were fixed in the JAAS included with
 * JDK1.4 and latter. This version allows LoginModules to be loaded from the
 * Thread context ClassLoader and uses an XML based configuration by default.
 *
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.1.2.3 $
 */
public class AppConfigurationEntry
{
   /** Enum class for the login module control flags
    */
   public static class LoginModuleControlFlag
   {
      public static final LoginModuleControlFlag REQUIRED = new LoginModuleControlFlag("required");
      public static final LoginModuleControlFlag REQUISITE = new LoginModuleControlFlag("requisite");
      public static final LoginModuleControlFlag SUFFICIENT = new LoginModuleControlFlag("sufficient");
      public static final LoginModuleControlFlag OPTIONAL =  new LoginModuleControlFlag("optional");

      private String flagName;

      private LoginModuleControlFlag(String flagName)
      {
         this.flagName = flagName;
      }
      public String toString()
      {
         return "LoginModuleControlFlag: " + flagName;
      }
   }

   private String loginModuleName;
   private LoginModuleControlFlag controlFlag;
   private Map options;

   public AppConfigurationEntry(String loginModuleName,
      AppConfigurationEntry.LoginModuleControlFlag controlFlag, Map options)
   {
      this.loginModuleName = loginModuleName;
      this.controlFlag = controlFlag;
      this.options = options;
   }

   public String getLoginModuleName()
   {
      return loginModuleName;
   }

   public LoginModuleControlFlag getControlFlag()
   {
      return controlFlag;
   }

   public Map getOptions()
   {
      return options;
   }
}
