/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package javax.security.auth.x500;

import java.io.InputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;

/** A noop X500Principal to get some web service stuff to compile under jdk1.3
 * 
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.1.2.2 $
 */
public final class X500Principal
{
   private byte[] encoded;

   public X500Principal(byte[] name)
   {
      encoded = name;
   }

   public X500Principal(InputStream is)
   {
      ByteArrayOutputStream baos = new ByteArrayOutputStream();
      byte[] tmp = new byte[1024];
      int count = 0;
      try
      {
         while( (count = is.read(tmp)) > 0 )
         {
            baos.write(tmp, 0, count);
         }
         is.close();
         encoded = baos.toByteArray();
      }
      catch(IOException e)
      {
         throw new IllegalArgumentException("IOException: "+e.getMessage());
      }
   }

   public X500Principal(String name)
   {
   }

   public byte[] getEncoded()
   {
      return encoded;
   }

   public String getName()
   {
      return "X500Principal";
   }

   public String getName(String format)
   {
      return "X500Principal";
   }
}
