/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.ejb.plugins.jaws.jdbc;

import java.sql.PreparedStatement;


/**
 * JDBCPreloadByPrimaryKey
 *
 * This finder be called on when read-ahead is turned on and findByPrimaryKey
 * is called.  It will read-ahead instead of just the old exists logic.
 *
 * @see <related>
 * @author <a href="mailto:bill@burkecentral.com">Bill Burke</a>
 * @version $Revision: 1.3.4.1 $
 */
public class JDBCPreloadByPrimaryKeyCommand extends JDBCPreloadFinderCommand
{
   // Constructors --------------------------------------------------

   public JDBCPreloadByPrimaryKeyCommand(JDBCCommandFactory factory)
   {
      super(factory, "PreloadByPrimaryKey");
      String sql = loadCommand.createSelectClause() + " FROM " + jawsEntity.getTableName() +
                   " WHERE " + getPkColumnWhereList();
      setSQL(sql);
   }

   // Public --------------------------------------------------------

   // JDBCQueryCommand overrides ------------------------------------

   protected void setParameters(PreparedStatement stmt, Object argOrArgs)
      throws Exception
   {
       Object[] objects = (Object[])argOrArgs;
       setPrimaryKeyParameters(stmt, 1, objects[0]);
   }
}
