/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.invocation.http.interfaces;

import java.net.HttpURLConnection;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;

/* An implementation of the HostnameVerifier that accepts any SSL certificate
hostname as matching the https URL that was used to initiate the SSL connection.
This is useful for testing SSL setup in development environments using self
signed SSL certificates.

 @author Scott.Stark@jboss.org
 @version $Revision: 1.1.4.3 $
 */
public class AnyhostVerifier implements InvocationHandler
{
   public static void setHostnameVerifier(HttpURLConnection conn)
      throws IllegalAccessException, InvocationTargetException
   {
      Class httpsConnClass = conn.getClass();
      ClassLoader loader = Thread.currentThread().getContextClassLoader();
      InvocationHandler handler = new AnyhostVerifier();
      // Get the HostnameVerifier type by calling getHostnameVerifier()
      Class hostnameVerifierClass = null;
      Method getHostnameVerifier = null;
      Method setHostnameVerifier = null;
      Class[] interfaces = {null};
      try
      {
         Class[] empty = {};
         getHostnameVerifier = httpsConnClass.getMethod("getHostnameVerifier", empty);
         hostnameVerifierClass = getHostnameVerifier.getReturnType();
         interfaces[0] = hostnameVerifierClass;
         setHostnameVerifier = httpsConnClass.getMethod("setHostnameVerifier", interfaces);
      }
      catch(NoSuchMethodException e)
      {
         throw new InvocationTargetException(e);
      }

      Object verifier = Proxy.newProxyInstance(loader, interfaces, handler);
      Object[] args = {verifier};
      setHostnameVerifier.invoke(conn, args);
   }

   /** An implementation of the com.sun.net.ssl.HostnameVerifier or 
    * javax.net.ssl.HostnameVerifier that returns true always.
    * 
    * @param proxy
    * @param method the HostnameVerifier method invocation
    * @param args the HostnameVerifier method args
    * @return Boolean.TRUE for anything but toString invocations
    * @throws Throwable
    */ 
   public Object invoke(Object proxy, Method method, Object[] args)
      throws Throwable
   {
      String name = method.getName();
      if( name.equals("toString"))
         return super.toString();
      return Boolean.TRUE;
   }
}
