/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.jmx.adaptor.rmi;

import javax.management.Notification;
import javax.management.NotificationListener;
import javax.management.ObjectName;
import org.jboss.logging.Logger;

/** A delegate that sits between the local MBeanServer and the remote client
 * providing the RMINotificationListener.
 * 
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.1.2.4 $
 */
public class NotificationListenerDelegate
   implements NotificationListener
{
   private static Logger log = Logger.getLogger(NotificationListenerDelegate.class);
   /** The remote client */
   private RMINotificationListener client;
   /** The server providing the RMIAdaptor interface */
   private RMIAdaptor server;
   /** The mbean the client is monitoring */
   private ObjectName targetName;

   public NotificationListenerDelegate(RMINotificationListener client)
   {
      this.client = client;
   }
   public NotificationListenerDelegate(RMINotificationListener client,
      ObjectName targetName, RMIAdaptor server)
   {
      this.client = client;
      this.targetName = targetName;
      this.server = server;
   }

   public void handleNotification(Notification notification,
      Object handback)
   {
      try
      {
         if( log.isTraceEnabled() )
         {
            log.trace("Sending notification to client, event:"+notification);
         }
         client.handleNotification(notification, handback);
      }
      catch(Throwable t)
      {
         log.debug("Failed to notify client", t);
         if( server != null )
         {
            log.debug("Unregistering listener due to previous error");
            try
            {
               server.removeNotificationListener(targetName, client);
            }
            catch(Exception e)
            {
               log.debug("Failed to unregister listener", e);
            }
         }
      }
   }
}
