/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.cache.test.generic;

import junit.framework.TestCase;
import org.jboss.cache.lock.LockMap;

/**
 * @author Ben Wang
 */
public class LockMapUnitTestCase extends TestCase
{
   private LockMap map_;

   /**
    * Constructor for LockMapTest.
    *
    * @param arg0
    */
   public LockMapUnitTestCase(String arg0)
   {
      super(arg0);
   }

   public static void main(String[] args)
   {
      junit.textui.TestRunner.run(LockMapUnitTestCase.class);
   }

   /*
    * @see TestCase#setUp()
    */
   protected void setUp() throws Exception
   {
      super.setUp();
      map_ = new LockMap();
   }

   /*
    * @see TestCase#tearDown()
    */
   protected void tearDown() throws Exception
   {
      super.tearDown();
      map_.removeAll();
   }

   final public void testIsOwner()
   {
      map_.addReader(this);
      assertTrue(map_.isOwner(this, LockMap.OWNER_READ));
      map_.addWriter(this);
      assertTrue(map_.isOwner(this, LockMap.OWNER_WRITE));
      assertTrue(map_.isOwner(this, LockMap.OWNER_ANY));
      map_.removeAll();
   }

   final public void testAddReader()
   {
      map_.addReader(this);
      assertTrue(map_.readerOwners().contains(this));
      map_.removeReader(this);
   }

   final public void testAddWriter()
   {
      map_.addWriter(this);
      assertTrue(map_.writerOwner().equals(this));
      map_.removeWriter(this);
   }

}
