/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.cache.test.local;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import org.jboss.cache.TreeCache;
import org.jboss.cache.lock.IsolationLevel;

/**
 * Unit test for local TreeCache with no tx.
 *
 * @version $Revision: 1.3.2.6 $
 */
public class NoTxUnitTestCase extends TestCase
{
   TreeCache cache;

   public NoTxUnitTestCase(String name)
   {
      super(name);
   }

   public void setUp() throws Exception
   {
      super.setUp();
      cache = new TreeCache();
      cache.setCacheMode(TreeCache.LOCAL);
      cache.setIsolationLevel(IsolationLevel.REPEATABLE_READ);
      cache.createService();
      cache.startService();
   }

   public void tearDown() throws Exception
   {
      super.tearDown();
      cache.stopService();
   }


   public void testPut()
   {
      try {
         cache.put("/a/b/c", "age", new Integer(38));
         assertEquals(cache.get("/a/b/c", "age"), new Integer(38));
         assertNotNull(cache.get("/a/b/c"));
      } catch (Exception e) {
         e.printStackTrace();
         fail(e.toString());
      }
   }

   public void testPutKeys()
   {
      try {
         cache.put("/a/b/c", "age", new Integer(38));
         cache.put("/a/b/c", "name", "Bela");
         assertEquals(cache.get("/a/b/c", "age"), new Integer(38));
         assertNotNull(cache.get("/a/b/c"));
         assertEquals(cache.getKeys("/a/b/c").size(), 2);
         assertEquals(cache.exists("/a/b/c"), true);
      } catch (Exception e) {
         e.printStackTrace();
         fail(e.toString());
      }
   }


   public static Test suite()
   {
      return new TestSuite(NoTxUnitTestCase.class);
   }

   public static void main(String[] args)
   {
      junit.textui.TestRunner.run(suite());
   }


}
