/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.jbossnet.admindevel;


import javax.ejb.EJBException;
import javax.ejb.SessionContext;
import java.rmi.RemoteException;

/**
 * The typical Hello Session Bean this time
 * as a web-service.
 * @author jung
 * @version $Revision: 1.1.4.2 $
 * @ejb:bean name="Hello"
 *           display-name="Hello World Bean"
 *           type="Stateless"
 *           view-type="remote"
 *           jndi-name="Hello"
 * @ejb:transaction type="Required"
 * @jboss-net:web-service urn="Hello"
 */
public class HelloBean implements javax.ejb.SessionBean
{
   /**
    * @jboss-net:web-method
    * @ejb:interface-method view-type="remote"
    */
   public String helloString(String name)
   {
      return "Hello " + name + "!";
   }

   /**
    * @jboss-net:web-method
    * @ejb:interface-method view-type="remote"
    */
   public HelloReplyObj helloBean(HelloObj bean)
   {
      HelloReplyObj hro = new HelloReplyObj();
      hro.setMsg(helloString(bean.getMsg()));
      return hro;
   }

   /**
    * @jboss-net:web-method
    * @ejb:interface-method view-type="remote"
    */
   public Object[] helloArray(Object[] query)
   {
      Object[] reply = new Object[query.length];
      for (int n = 0; n < query.length; n++)
      {
         HelloObj hello = (HelloObj)query[n];
         HelloReplyObj hro = new HelloReplyObj();
         hro.setMsg(helloString(hello.getMsg()));
         reply[n] = hro;
      }
      return reply;
   }

   public void setSessionContext(SessionContext ctx) throws EJBException, RemoteException
   {
   }

   public void ejbCreate()
   {
   }

   public void ejbRemove()
   {
   }

   public void ejbActivate()
   {
   }

   public void ejbPassivate()
   {
   }
}
