/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.jbossnet.basic;

import junit.framework.Test;
import junit.framework.TestSuite;
import org.jboss.test.jbossnet.JBossNetTestBase;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.URL;

/**
 * Tests remote accessibility of the main axis service servlet
 * @since 11. Oktober 2001
 * @author <a href="mailto:Christoph.Jung@infor.de">Christoph G. Jung</a>
 * @author Thomas.Diesler@jboss.org
 * @version $Revision: 1.1.1.1.4.5 $
 */

public class AxisUnitTestCase extends JBossNetTestBase
{

   // Constructors --------------------------------------------------
   public AxisUnitTestCase(String name)
   {
      super(name);
   }

   /** tests availability of the servlet under various contexts */
   public void testServlet() throws Exception
   {
      doLegalAccess("Servlet availability", new URL("http://" + getServerHost() + ":8080/jboss-net/servlet/AxisServlet"));
      doLegalAccess("service availability", new URL("http://" + getServerHost() + ":8080/jboss-net/services"));
   }

   /** tests a successful http call to the given target */
   private void doLegalAccess(String message, URL target) throws Exception
   {
      BufferedReader reader = new BufferedReader(new InputStreamReader(target.openStream()));
      try
      {
         String line = reader.readLine();
         assertNotNull(message + " proper response", line);
      }
      finally
      {
         reader.close();
      }
   }

   public static Test suite() throws Exception
   {
      // nothing to deploy really
      return new TestSuite(AxisUnitTestCase.class);
   }
}
