/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.jca.test;

import javax.transaction.TransactionRolledbackException;
import junit.framework.*;

import org.jboss.test.JBossTestCase;
import org.jboss.test.jca.interfaces.XAExceptionSessionHome;
import org.jboss.test.jca.interfaces.XAExceptionSession;
import org.jboss.test.jca.interfaces.XAExceptionTestSessionHome;
import org.jboss.test.jca.interfaces.XAExceptionTestSession;


/**
 * XAExceptionUnitTestCase.java
 *
 *
 * Created: Tue Sep 10 21:46:18 2002
 *
 * @author <a href="mailto:d_jencks@users.sourceforge.net">David Jencks</a>
 * @version
 */

public class XAExceptionUnitTestCase extends JBossTestCase
{
   public XAExceptionUnitTestCase(String name)
   {
      super(name);
   }

   public static Test suite() throws Exception
   {
      Test t1 = getDeploySetup(XAExceptionUnitTestCase.class, "jcatest.jar");
      Test t2 = getDeploySetup(t1, "testadapter-ds.xml");
      return getDeploySetup(t2, "jbosstestadapter.rar");
   }

   public void testXAExceptionToTransactionRolledbackException() throws Exception
   {
      XAExceptionSessionHome xh = (XAExceptionSessionHome)getInitialContext().lookup("test/XAExceptionSessionHome");
      XAExceptionSession x = xh.create();
      try
      {
         x.testXAExceptionToTransactionRolledbackException();
      }
      catch (TransactionRolledbackException tre)
      {
         getLog().info("testXAExceptionToRollbackException passed");
         return;
      } // end of try-catch
      fail("expected TransactionRolledbackException not thrown");
   }

   public void testXAExceptionToTransactionRolledbackExceptionOnServer() throws Exception
   {
      XAExceptionTestSessionHome xth = (XAExceptionTestSessionHome)getInitialContext().lookup("test/XAExceptionTestSessionHome");
      XAExceptionTestSession xt = xth.create();
      xt.testXAExceptionToTransactionRolledbackException();
   }

   public void testXAExceptionToTransactionRolledbackLocalExceptionOnServer() throws Exception
   {
      XAExceptionTestSessionHome xth = (XAExceptionTestSessionHome)getInitialContext().lookup("test/XAExceptionTestSessionHome");
      XAExceptionTestSession xt = xth.create();
      xt.testXAExceptionToTransactionRolledbackLocalException();
   }

   public void testRMERRInOnePCToTransactionRolledbackException() throws Exception
   {
      XAExceptionSessionHome xh = (XAExceptionSessionHome)getInitialContext().lookup("test/XAExceptionSessionHome");
      XAExceptionSession x = xh.create();
      try
      {
         x.testRMERRInOnePCToTransactionRolledbackException();
      }
      catch (TransactionRolledbackException tre)
      {
         getLog().info("testXAExceptionToRollbackException passed");
         return;
      } // end of try-catch
      fail("expected TransactionRolledbackException not thrown");
   }

   public void testRMERRInOnePCToTransactionRolledbackExceptionOnServer() throws Exception
   {
      XAExceptionTestSessionHome xth = (XAExceptionTestSessionHome)getInitialContext().lookup("test/XAExceptionTestSessionHome");
      XAExceptionTestSession xt = xth.create();
      xt.testRMERRInOnePCToTransactionRolledbackException();
   }

   public void testXAExceptionToTransactionRolledbacLocalkExceptionOnServer() throws Exception
   {
      XAExceptionTestSessionHome xth = (XAExceptionTestSessionHome)getInitialContext().lookup("test/XAExceptionTestSessionHome");
      XAExceptionTestSession xt = xth.create();
      xt.testXAExceptionToTransactionRolledbacLocalkException();
   }

   public void testSimulateConnectionError() throws Exception
   {
      XAExceptionSessionHome xh = (XAExceptionSessionHome)getInitialContext().lookup("test/XAExceptionSessionHome");
      XAExceptionSession x = xh.create();
      x.simulateConnectionError();
   }

   public void testSimulateConnectionErrorWithTwoHandles() throws Exception
   {
      XAExceptionSessionHome xh = (XAExceptionSessionHome)getInitialContext().lookup("test/XAExceptionSessionHome");
      XAExceptionSession x = xh.create();
      x.simulateConnectionErrorWithTwoHandles();
   }

   public void testGetConnectionResourceError() throws Exception
   {
      XAExceptionSessionHome xh = (XAExceptionSessionHome)getInitialContext().lookup("test/XAExceptionSessionHome");
      XAExceptionSession x = xh.create();
      x.simulateError("getConnectionResource", 10);
   }

   public void testGetConnectionRuntimeError() throws Exception
   {
      XAExceptionSessionHome xh = (XAExceptionSessionHome)getInitialContext().lookup("test/XAExceptionSessionHome");
      XAExceptionSession x = xh.create();
      x.simulateError("getConnectionRuntime", 10);
   }

   public void testCreateManagedConnectionResourceError() throws Exception
   {
      XAExceptionSessionHome xh = (XAExceptionSessionHome)getInitialContext().lookup("test/XAExceptionSessionHome");
      XAExceptionSession x = xh.create();
      x.simulateFactoryError("createManagedConnectionResource", 10);
   }

   public void testCreateManagedConnectionRuntimeError() throws Exception
   {
      XAExceptionSessionHome xh = (XAExceptionSessionHome)getInitialContext().lookup("test/XAExceptionSessionHome");
      XAExceptionSession x = xh.create();
      x.simulateFactoryError("createManagedConnectionRuntime", 10);
   }

   public void testMatchManagedConnectionResourceError() throws Exception
   {
      XAExceptionSessionHome xh = (XAExceptionSessionHome)getInitialContext().lookup("test/XAExceptionSessionHome");
      XAExceptionSession x = xh.create();
      x.simulateFactoryError("matchManagedConnectionResource", 10);
   }

   public void testMatchManagedConnectionRuntimeError() throws Exception
   {
      XAExceptionSessionHome xh = (XAExceptionSessionHome)getInitialContext().lookup("test/XAExceptionSessionHome");
      XAExceptionSession x = xh.create();
      x.simulateFactoryError("matchManagedConnectionRuntime", 10);
   }

}// XAExceptionUnitTestCase
