/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.web.servlets;

import java.io.IOException;
import javax.servlet.Filter;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.FilterChain;
import javax.security.auth.Subject;
import javax.naming.NamingException;
import javax.naming.InitialContext;

/**
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.1.2.1 $
 */
public class SubjectFilter implements Filter
{
   public void init(FilterConfig filterConfig) throws ServletException
   {
      
   }

   public void doFilter(ServletRequest request, ServletResponse response,
      FilterChain filterChain)
      throws IOException, ServletException
   {
      try
      {
         Subject userSubject = getActiveSubject();
         if( userSubject == null )
            throw new ServletException("Active subject was null");
      }
      catch(NamingException e)
      {
         throw new ServletException("Failed to lookup active subject", e);        
      }
      filterChain.doFilter(request, response);
   }

   public void destroy()
   {
   }

   protected Subject getActiveSubject() throws NamingException
   {
      InitialContext ctx = new InitialContext();
      Subject s = (Subject) ctx.lookup("java:comp/env/security/subject");
      return s;
   }
}
