/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.web.tomcat.security;

import java.io.IOException;
import javax.servlet.ServletException;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletResponse;

import org.apache.catalina.valves.ValveBase;
import org.apache.catalina.Request;
import org.apache.catalina.Response;
import org.apache.catalina.ValveContext;
import org.jboss.logging.Logger;

/** A valve that provides information on the jaas login exception seen in the
 SecurityAssociation exception data. The exceptionHeader attribute if set is the
 header name that should be populated with the exception message.
   
 @author Scott.Stark@jboss.org
 @version $Revision: 1.1.4.4 $
 */
public class BasicAuthValve
   extends ValveBase
{
   private static Logger log = Logger.getLogger(BasicAuthValve.class);
   private static boolean trace = log.isTraceEnabled();

   private String exceptionHeader = null;

   public String getExceptionHeader()
   {
      return exceptionHeader;
   }
   public void setExceptionHeader(String exceptionHeader)
   {
      this.exceptionHeader = exceptionHeader;
   }

   public void invoke(Request request, Response response, ValveContext context)
      throws IOException, ServletException
   {
      context.invokeNext(request, response);
      // Check the SecurityAssociation context exception
      Throwable t = SecurityAssociationActions.getAuthException();
      ServletResponse sr = response.getResponse();
      if( (sr instanceof HttpServletResponse) == false )
         return;

      HttpServletResponse hsr = (HttpServletResponse) sr;
      boolean isError = response.isError();
      if( trace )
         log.trace("IsError: "+isError+"SecurityAssociation.exception: ", t);
      if( isError && t != null )
      {
         String msg = t.getMessage();
         // Set the response exception header
         if( exceptionHeader != null )
            hsr.setHeader(exceptionHeader, msg);
      }
   }
}
