/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.monitor.alarm;

import javax.management.ObjectName;

/**
 * AlarmKey
 *
 * An alarm is equivalent if serverId/source/type match
 *
 * @author  <a href="mailto:dimitris@jboss.org">Dimitris Andreadis</a>
 *
 * @version $Revision: 1.1.2.3 $
**/
class AlarmKey
{
   // Constants -----------------------------------------------------
   
   public static final String BAD_SOURCE = "NonObjectNameSource";

   // Private Data --------------------------------------------------
   
   private String alarmId;

   // Static Helper -------------------------------------------------  
   
   public static AlarmKey createKey(String serverId, Object source, String type)
   {
      if (source instanceof ObjectName)
         return new AlarmKey(serverId, source.toString(), type);
      else if (source instanceof String)
         return new AlarmKey(serverId, (String)source, type);
      else
         return new AlarmKey(serverId, BAD_SOURCE, type);      
   }
   
   // Constructor ---------------------------------------------------
   
   public AlarmKey(String serverId, String source, String type)
   {
      StringBuffer sbuf = new StringBuffer(256);
      
      sbuf.append(serverId);
      sbuf.append('+').append(source);
      sbuf.append('+').append(type);
      
      alarmId = sbuf.toString();
   }
   
   // Object stuff --------------------------------------------------
   
   /**
    * Bases equality on alarmId equality
   **/
   public boolean equals(Object obj)
   {
      if (obj instanceof AlarmKey)
         return ((AlarmKey)obj).alarmId.equals(this.alarmId);
      else
         return false;
   }
   
   /**
    * Makes use of alarmId's hashCode
   **/
   public int hashCode()
   {
      return this.alarmId.hashCode();
   }
   
   /**
    * Pretty prints
   **/
   public String toString()
   {
      StringBuffer sbuf = new StringBuffer(256);
      
      sbuf.append("AlarmKey[").append(this.alarmId).append("]");
      
      return sbuf.toString();
   }
}
