/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.web.loadbalancer.monitor;

import org.apache.commons.httpclient.HttpMethod;
import gnu.regexp.RE;
import gnu.regexp.REException;

/**
 * A Monitor implementation that does a RegExp-check of the content.
 *
 * @author Thomas Peuss <jboss@peuss.de>
 * @version $Revision: 1.3.2.2 $
 * @jmx:mbean name="jboss.web.loadbalancer: service=ECVMonitor"
 *            extends="org.jboss.web.loadbalancer.monitor.AbstractMonitorMBean"
 */
public class ECVMonitorService
    extends AbstractMonitor
    implements ECVMonitorServiceMBean
{
  protected RE regExp;

  protected boolean checkHostStatus(HttpMethod method)
  {
    return matchRegExp(method.getResponseBodyAsString());
  }

  protected boolean matchRegExp(String string)
  {
    // try to match regexp
    if (regExp.getMatch(string) == null)
    {
      log.error("RegExp \"" + regExp + "\" does not match server output");
      return false;
    }
    return true;
  }

  /**
   * @jmx:managed-attribute
   */
  public void setRegExp(String regExp) throws REException
  {
    this.regExp = new RE(regExp);
  }

  /**
   * @jmx:managed-attribute
   */
  public String getRegExp()
  {
    return regExp.toString();
  }
}